Class: Aws::RolesAnywhere::Client
- Inherits:
-
Seahorse::Client::Base
- Object
- Seahorse::Client::Base
- Aws::RolesAnywhere::Client
- Includes:
- ClientStubs
- Defined in:
- lib/aws-sdk-rolesanywhere/client.rb,
sig/client.rbs
Overview
An API client for RolesAnywhere. To construct a client, you need to configure a :region and :credentials.
client = Aws::RolesAnywhere::Client.new(
region: region_name,
credentials: credentials,
# ...
)
For details on configuring region and credentials see the developer guide.
See #initialize for a full list of supported configuration options.
Defined Under Namespace
Modules: _CreateProfileResponseSuccess, _CreateTrustAnchorResponseSuccess, _DeleteAttributeMappingResponseSuccess, _DeleteCrlResponseSuccess, _DeleteProfileResponseSuccess, _DeleteTrustAnchorResponseSuccess, _DisableCrlResponseSuccess, _DisableProfileResponseSuccess, _DisableTrustAnchorResponseSuccess, _EnableCrlResponseSuccess, _EnableProfileResponseSuccess, _EnableTrustAnchorResponseSuccess, _GetCrlResponseSuccess, _GetProfileResponseSuccess, _GetSubjectResponseSuccess, _GetTrustAnchorResponseSuccess, _ImportCrlResponseSuccess, _ListCrlsResponseSuccess, _ListProfilesResponseSuccess, _ListSubjectsResponseSuccess, _ListTagsForResourceResponseSuccess, _ListTrustAnchorsResponseSuccess, _PutAttributeMappingResponseSuccess, _PutNotificationSettingsResponseSuccess, _ResetNotificationSettingsResponseSuccess, _TagResourceResponseSuccess, _UntagResourceResponseSuccess, _UpdateCrlResponseSuccess, _UpdateProfileResponseSuccess, _UpdateTrustAnchorResponseSuccess
Class Attribute Summary collapse
- .identifier ⇒ Object readonly private
API Operations collapse
-
#create_profile(params = {}) ⇒ Types::ProfileDetailResponse
Creates a profile, a list of the roles that Roles Anywhere service is trusted to assume.
-
#create_trust_anchor(params = {}) ⇒ Types::TrustAnchorDetailResponse
Creates a trust anchor to establish trust between IAM Roles Anywhere and your certificate authority (CA).
-
#delete_attribute_mapping(params = {}) ⇒ Types::DeleteAttributeMappingResponse
Delete an entry from the attribute mapping rules enforced by a given profile.
-
#delete_crl(params = {}) ⇒ Types::CrlDetailResponse
Deletes a certificate revocation list (CRL).
-
#delete_profile(params = {}) ⇒ Types::ProfileDetailResponse
Deletes a profile.
-
#delete_trust_anchor(params = {}) ⇒ Types::TrustAnchorDetailResponse
Deletes a trust anchor.
-
#disable_crl(params = {}) ⇒ Types::CrlDetailResponse
Disables a certificate revocation list (CRL).
-
#disable_profile(params = {}) ⇒ Types::ProfileDetailResponse
Disables a profile.
-
#disable_trust_anchor(params = {}) ⇒ Types::TrustAnchorDetailResponse
Disables a trust anchor.
-
#enable_crl(params = {}) ⇒ Types::CrlDetailResponse
Enables a certificate revocation list (CRL).
-
#enable_profile(params = {}) ⇒ Types::ProfileDetailResponse
Enables temporary credential requests for a profile.
-
#enable_trust_anchor(params = {}) ⇒ Types::TrustAnchorDetailResponse
Enables a trust anchor.
-
#get_crl(params = {}) ⇒ Types::CrlDetailResponse
Gets a certificate revocation list (CRL).
-
#get_profile(params = {}) ⇒ Types::ProfileDetailResponse
Gets a profile.
-
#get_subject(params = {}) ⇒ Types::SubjectDetailResponse
Gets a subject, which associates a certificate identity with authentication attempts.
-
#get_trust_anchor(params = {}) ⇒ Types::TrustAnchorDetailResponse
Gets a trust anchor.
-
#import_crl(params = {}) ⇒ Types::CrlDetailResponse
Imports the certificate revocation list (CRL).
-
#list_crls(params = {}) ⇒ Types::ListCrlsResponse
Lists all certificate revocation lists (CRL) in the authenticated account and Amazon Web Services Region.
-
#list_profiles(params = {}) ⇒ Types::ListProfilesResponse
Lists all profiles in the authenticated account and Amazon Web Services Region.
-
#list_subjects(params = {}) ⇒ Types::ListSubjectsResponse
Lists the subjects in the authenticated account and Amazon Web Services Region.
-
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceResponse
Lists the tags attached to the resource.
-
#list_trust_anchors(params = {}) ⇒ Types::ListTrustAnchorsResponse
Lists the trust anchors in the authenticated account and Amazon Web Services Region.
-
#put_attribute_mapping(params = {}) ⇒ Types::PutAttributeMappingResponse
Put an entry in the attribute mapping rules that will be enforced by a given profile.
-
#put_notification_settings(params = {}) ⇒ Types::PutNotificationSettingsResponse
Attaches a list of notification settings to a trust anchor.
-
#reset_notification_settings(params = {}) ⇒ Types::ResetNotificationSettingsResponse
Resets the custom notification setting to IAM Roles Anywhere default setting.
-
#tag_resource(params = {}) ⇒ Struct
Attaches tags to a resource.
-
#untag_resource(params = {}) ⇒ Struct
Removes tags from the resource.
-
#update_crl(params = {}) ⇒ Types::CrlDetailResponse
Updates the certificate revocation list (CRL).
-
#update_profile(params = {}) ⇒ Types::ProfileDetailResponse
Updates a profile, a list of the roles that IAM Roles Anywhere service is trusted to assume.
-
#update_trust_anchor(params = {}) ⇒ Types::TrustAnchorDetailResponse
Updates a trust anchor.
Class Method Summary collapse
- .errors_module ⇒ Object private
- .new ⇒ Object
Instance Method Summary collapse
- #build_request(operation_name, params = {}) ⇒ Object private
-
#initialize(options) ⇒ Client
constructor
A new instance of Client.
- #waiter_names ⇒ Object deprecated private Deprecated.
Constructor Details
#initialize(options) ⇒ Client
Returns a new instance of Client.
471 472 473 |
# File 'lib/aws-sdk-rolesanywhere/client.rb', line 471 def initialize(*args) super end |
Class Attribute Details
.identifier ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
2245 2246 2247 |
# File 'lib/aws-sdk-rolesanywhere/client.rb', line 2245 def identifier @identifier end |
Class Method Details
.errors_module ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
2248 2249 2250 |
# File 'lib/aws-sdk-rolesanywhere/client.rb', line 2248 def errors_module Errors end |
.new ⇒ Object
14 |
# File 'sig/client.rbs', line 14
def self.new: (
|
Instance Method Details
#build_request(operation_name, params = {}) ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
2218 2219 2220 2221 2222 2223 2224 2225 2226 2227 2228 2229 2230 2231 2232 2233 2234 |
# File 'lib/aws-sdk-rolesanywhere/client.rb', line 2218 def build_request(operation_name, params = {}) handlers = @handlers.for(operation_name) tracer = config.telemetry_provider.tracer_provider.tracer( Aws::Telemetry.module_to_tracer_name('Aws::RolesAnywhere') ) context = Seahorse::Client::RequestContext.new( operation_name: operation_name, operation: config.api.operation(operation_name), client: self, params: params, config: config, tracer: tracer ) context[:gem_name] = 'aws-sdk-rolesanywhere' context[:gem_version] = '1.54.0' Seahorse::Client::Request.new(handlers, context) end |
#create_profile(params = {}) ⇒ Types::ProfileDetailResponse
Creates a profile, a list of the roles that Roles Anywhere service is trusted to assume. You use profiles to intersect permissions with IAM managed policies.
Required permissions: rolesanywhere:CreateProfile.
86 |
# File 'sig/client.rbs', line 86
def create_profile: (
|
#create_trust_anchor(params = {}) ⇒ Types::TrustAnchorDetailResponse
Creates a trust anchor to establish trust between IAM Roles Anywhere and your certificate authority (CA). You can define a trust anchor as a reference to an Private Certificate Authority (Private CA) or by uploading a CA certificate. Your Amazon Web Services workloads can authenticate with the trust anchor using certificates issued by the CA in exchange for temporary Amazon Web Services credentials.
Required permissions: rolesanywhere:CreateTrustAnchor.
109 |
# File 'sig/client.rbs', line 109
def create_trust_anchor: (
|
#delete_attribute_mapping(params = {}) ⇒ Types::DeleteAttributeMappingResponse
Delete an entry from the attribute mapping rules enforced by a given profile.
141 |
# File 'sig/client.rbs', line 141
def delete_attribute_mapping: (
|
#delete_crl(params = {}) ⇒ Types::CrlDetailResponse
Deletes a certificate revocation list (CRL).
Required permissions: rolesanywhere:DeleteCrl.
153 |
# File 'sig/client.rbs', line 153
def delete_crl: (
|
#delete_profile(params = {}) ⇒ Types::ProfileDetailResponse
Deletes a profile.
Required permissions: rolesanywhere:DeleteProfile.
163 |
# File 'sig/client.rbs', line 163
def delete_profile: (
|
#delete_trust_anchor(params = {}) ⇒ Types::TrustAnchorDetailResponse
Deletes a trust anchor.
Required permissions: rolesanywhere:DeleteTrustAnchor.
173 |
# File 'sig/client.rbs', line 173
def delete_trust_anchor: (
|
#disable_crl(params = {}) ⇒ Types::CrlDetailResponse
Disables a certificate revocation list (CRL).
Required permissions: rolesanywhere:DisableCrl.
183 |
# File 'sig/client.rbs', line 183
def disable_crl: (
|
#disable_profile(params = {}) ⇒ Types::ProfileDetailResponse
Disables a profile. When disabled, temporary credential requests with this profile fail.
Required permissions: rolesanywhere:DisableProfile.
193 |
# File 'sig/client.rbs', line 193
def disable_profile: (
|
#disable_trust_anchor(params = {}) ⇒ Types::TrustAnchorDetailResponse
Disables a trust anchor. When disabled, temporary credential requests specifying this trust anchor are unauthorized.
Required permissions: rolesanywhere:DisableTrustAnchor.
203 |
# File 'sig/client.rbs', line 203
def disable_trust_anchor: (
|
#enable_crl(params = {}) ⇒ Types::CrlDetailResponse
Enables a certificate revocation list (CRL). When enabled, certificates stored in the CRL are unauthorized to receive session credentials.
Required permissions: rolesanywhere:EnableCrl.
213 |
# File 'sig/client.rbs', line 213
def enable_crl: (
|
#enable_profile(params = {}) ⇒ Types::ProfileDetailResponse
Enables temporary credential requests for a profile.
Required permissions: rolesanywhere:EnableProfile.
223 |
# File 'sig/client.rbs', line 223
def enable_profile: (
|
#enable_trust_anchor(params = {}) ⇒ Types::TrustAnchorDetailResponse
Enables a trust anchor. When enabled, certificates in the trust anchor chain are authorized for trust validation.
Required permissions: rolesanywhere:EnableTrustAnchor.
233 |
# File 'sig/client.rbs', line 233
def enable_trust_anchor: (
|
#get_crl(params = {}) ⇒ Types::CrlDetailResponse
Gets a certificate revocation list (CRL).
Required permissions: rolesanywhere:GetCrl.
243 |
# File 'sig/client.rbs', line 243
def get_crl: (
|
#get_profile(params = {}) ⇒ Types::ProfileDetailResponse
Gets a profile.
Required permissions: rolesanywhere:GetProfile.
253 |
# File 'sig/client.rbs', line 253
def get_profile: (
|
#get_subject(params = {}) ⇒ Types::SubjectDetailResponse
Gets a subject, which associates a certificate identity with authentication attempts. The subject stores auditing information such as the status of the last authentication attempt, the certificate data used in the attempt, and the last time the associated identity attempted authentication.
Required permissions: rolesanywhere:GetSubject.
263 |
# File 'sig/client.rbs', line 263
def get_subject: (
|
#get_trust_anchor(params = {}) ⇒ Types::TrustAnchorDetailResponse
Gets a trust anchor.
Required permissions: rolesanywhere:GetTrustAnchor.
273 |
# File 'sig/client.rbs', line 273
def get_trust_anchor: (
|
#import_crl(params = {}) ⇒ Types::CrlDetailResponse
Imports the certificate revocation list (CRL). A CRL is a list of certificates that have been revoked by the issuing certificate Authority (CA).In order to be properly imported, a CRL must be in PEM format. IAM Roles Anywhere validates against the CRL before issuing credentials.
Required permissions: rolesanywhere:ImportCrl.
283 |
# File 'sig/client.rbs', line 283
def import_crl: (
|
#list_crls(params = {}) ⇒ Types::ListCrlsResponse
Lists all certificate revocation lists (CRL) in the authenticated account and Amazon Web Services Region.
Required permissions: rolesanywhere:ListCrls.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
303 |
# File 'sig/client.rbs', line 303
def list_crls: (
|
#list_profiles(params = {}) ⇒ Types::ListProfilesResponse
Lists all profiles in the authenticated account and Amazon Web Services Region.
Required permissions: rolesanywhere:ListProfiles.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
315 |
# File 'sig/client.rbs', line 315
def list_profiles: (
|
#list_subjects(params = {}) ⇒ Types::ListSubjectsResponse
Lists the subjects in the authenticated account and Amazon Web Services Region.
Required permissions: rolesanywhere:ListSubjects.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
327 |
# File 'sig/client.rbs', line 327
def list_subjects: (
|
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceResponse
Lists the tags attached to the resource.
Required permissions: rolesanywhere:ListTagsForResource.
338 |
# File 'sig/client.rbs', line 338
def list_tags_for_resource: (
|
#list_trust_anchors(params = {}) ⇒ Types::ListTrustAnchorsResponse
Lists the trust anchors in the authenticated account and Amazon Web Services Region.
Required permissions: rolesanywhere:ListTrustAnchors.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
349 |
# File 'sig/client.rbs', line 349
def list_trust_anchors: (
|
#put_attribute_mapping(params = {}) ⇒ Types::PutAttributeMappingResponse
Put an entry in the attribute mapping rules that will be enforced by a given profile. A mapping specifies a certificate field and one or more specifiers that have contextual meanings.
360 |
# File 'sig/client.rbs', line 360
def put_attribute_mapping: (
|
#put_notification_settings(params = {}) ⇒ Types::PutNotificationSettingsResponse
Attaches a list of notification settings to a trust anchor.
A notification setting includes information such as event name, threshold, status of the notification setting, and the channel to notify.
Required permissions: rolesanywhere:PutNotificationSettings.
376 |
# File 'sig/client.rbs', line 376
def put_notification_settings: (
|
#reset_notification_settings(params = {}) ⇒ Types::ResetNotificationSettingsResponse
Resets the custom notification setting to IAM Roles Anywhere default setting.
Required permissions:
rolesanywhere:ResetNotificationSettings.
394 |
# File 'sig/client.rbs', line 394
def reset_notification_settings: (
|
#tag_resource(params = {}) ⇒ Struct
Attaches tags to a resource.
Required permissions: rolesanywhere:TagResource.
409 |
# File 'sig/client.rbs', line 409
def tag_resource: (
|
#untag_resource(params = {}) ⇒ Struct
Removes tags from the resource.
Required permissions: rolesanywhere:UntagResource.
424 |
# File 'sig/client.rbs', line 424
def untag_resource: (
|
#update_crl(params = {}) ⇒ Types::CrlDetailResponse
Updates the certificate revocation list (CRL). A CRL is a list of certificates that have been revoked by the issuing certificate authority (CA). IAM Roles Anywhere validates against the CRL before issuing credentials.
Required permissions: rolesanywhere:UpdateCrl.
435 |
# File 'sig/client.rbs', line 435
def update_crl: (
|
#update_profile(params = {}) ⇒ Types::ProfileDetailResponse
Updates a profile, a list of the roles that IAM Roles Anywhere service is trusted to assume. You use profiles to intersect permissions with IAM managed policies.
Required permissions: rolesanywhere:UpdateProfile.
447 |
# File 'sig/client.rbs', line 447
def update_profile: (
|
#update_trust_anchor(params = {}) ⇒ Types::TrustAnchorDetailResponse
Updates a trust anchor. You establish trust between IAM Roles Anywhere and your certificate authority (CA) by configuring a trust anchor. You can define a trust anchor as a reference to an Private Certificate Authority (Private CA) or by uploading a CA certificate. Your Amazon Web Services workloads can authenticate with the trust anchor using certificates issued by the CA in exchange for temporary Amazon Web Services credentials.
Required permissions: rolesanywhere:UpdateTrustAnchor.
463 |
# File 'sig/client.rbs', line 463
def update_trust_anchor: (
|
#waiter_names ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
2238 2239 2240 |
# File 'lib/aws-sdk-rolesanywhere/client.rb', line 2238 def waiter_names [] end |