Class: Aws::RolesAnywhere::Types::DeleteAttributeMappingResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::RolesAnywhere::Types::DeleteAttributeMappingResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-rolesanywhere/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#profile ⇒ Types::ProfileDetail
The state of the profile after a read or write operation.
Instance Attribute Details
#profile ⇒ Types::ProfileDetail
The state of the profile after a read or write operation.
284 285 286 287 288 |
# File 'lib/aws-sdk-rolesanywhere/types.rb', line 284 class DeleteAttributeMappingResponse < Struct.new( :profile) SENSITIVE = [] include Aws::Structure end |