Class: Aws::RolesAnywhere::Types::UpdateTrustAnchorRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::RolesAnywhere::Types::UpdateTrustAnchorRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-rolesanywhere/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#name ⇒ String
The name of the trust anchor.
-
#source ⇒ Types::Source
The trust anchor type and its related certificate data.
-
#trust_anchor_id ⇒ String
The unique identifier of the trust anchor.
Instance Attribute Details
#name ⇒ String
The name of the trust anchor.
1242 1243 1244 1245 1246 1247 1248 |
# File 'lib/aws-sdk-rolesanywhere/types.rb', line 1242 class UpdateTrustAnchorRequest < Struct.new( :trust_anchor_id, :name, :source) SENSITIVE = [] include Aws::Structure end |
#source ⇒ Types::Source
The trust anchor type and its related certificate data.
1242 1243 1244 1245 1246 1247 1248 |
# File 'lib/aws-sdk-rolesanywhere/types.rb', line 1242 class UpdateTrustAnchorRequest < Struct.new( :trust_anchor_id, :name, :source) SENSITIVE = [] include Aws::Structure end |
#trust_anchor_id ⇒ String
The unique identifier of the trust anchor.
1242 1243 1244 1245 1246 1247 1248 |
# File 'lib/aws-sdk-rolesanywhere/types.rb', line 1242 class UpdateTrustAnchorRequest < Struct.new( :trust_anchor_id, :name, :source) SENSITIVE = [] include Aws::Structure end |