Class: Aws::RolesAnywhere::Client
- Inherits:
-
Seahorse::Client::Base
- Object
- Seahorse::Client::Base
- Aws::RolesAnywhere::Client
- Includes:
- ClientStubs
- Defined in:
- lib/aws-sdk-rolesanywhere/client.rb
Overview
An API client for RolesAnywhere. To construct a client, you need to configure a ‘:region` and `:credentials`.
client = Aws::RolesAnywhere::Client.new(
region: region_name,
credentials: credentials,
# ...
)
For details on configuring region and credentials see the [developer guide](/sdk-for-ruby/v3/developer-guide/setup-config.html).
See #initialize for a full list of supported configuration options.
Class Attribute Summary collapse
- .identifier ⇒ Object readonly private
API Operations collapse
-
#create_profile(params = {}) ⇒ Types::ProfileDetailResponse
Creates a profile, a list of the roles that Roles Anywhere service is trusted to assume.
-
#create_trust_anchor(params = {}) ⇒ Types::TrustAnchorDetailResponse
Creates a trust anchor to establish trust between IAM Roles Anywhere and your certificate authority (CA).
-
#delete_attribute_mapping(params = {}) ⇒ Types::DeleteAttributeMappingResponse
Delete an entry from the attribute mapping rules enforced by a given profile.
-
#delete_crl(params = {}) ⇒ Types::CrlDetailResponse
Deletes a certificate revocation list (CRL).
-
#delete_profile(params = {}) ⇒ Types::ProfileDetailResponse
Deletes a profile.
-
#delete_trust_anchor(params = {}) ⇒ Types::TrustAnchorDetailResponse
Deletes a trust anchor.
-
#disable_crl(params = {}) ⇒ Types::CrlDetailResponse
Disables a certificate revocation list (CRL).
-
#disable_profile(params = {}) ⇒ Types::ProfileDetailResponse
Disables a profile.
-
#disable_trust_anchor(params = {}) ⇒ Types::TrustAnchorDetailResponse
Disables a trust anchor.
-
#enable_crl(params = {}) ⇒ Types::CrlDetailResponse
Enables a certificate revocation list (CRL).
-
#enable_profile(params = {}) ⇒ Types::ProfileDetailResponse
Enables temporary credential requests for a profile.
-
#enable_trust_anchor(params = {}) ⇒ Types::TrustAnchorDetailResponse
Enables a trust anchor.
-
#get_crl(params = {}) ⇒ Types::CrlDetailResponse
Gets a certificate revocation list (CRL).
-
#get_profile(params = {}) ⇒ Types::ProfileDetailResponse
Gets a profile.
-
#get_subject(params = {}) ⇒ Types::SubjectDetailResponse
Gets a subject, which associates a certificate identity with authentication attempts.
-
#get_trust_anchor(params = {}) ⇒ Types::TrustAnchorDetailResponse
Gets a trust anchor.
-
#import_crl(params = {}) ⇒ Types::CrlDetailResponse
Imports the certificate revocation list (CRL).
-
#list_crls(params = {}) ⇒ Types::ListCrlsResponse
Lists all certificate revocation lists (CRL) in the authenticated account and Amazon Web Services Region.
-
#list_profiles(params = {}) ⇒ Types::ListProfilesResponse
Lists all profiles in the authenticated account and Amazon Web Services Region.
-
#list_subjects(params = {}) ⇒ Types::ListSubjectsResponse
Lists the subjects in the authenticated account and Amazon Web Services Region.
-
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceResponse
Lists the tags attached to the resource.
-
#list_trust_anchors(params = {}) ⇒ Types::ListTrustAnchorsResponse
Lists the trust anchors in the authenticated account and Amazon Web Services Region.
-
#put_attribute_mapping(params = {}) ⇒ Types::PutAttributeMappingResponse
Put an entry in the attribute mapping rules that will be enforced by a given profile.
-
#put_notification_settings(params = {}) ⇒ Types::PutNotificationSettingsResponse
Attaches a list of *notification settings* to a trust anchor.
-
#reset_notification_settings(params = {}) ⇒ Types::ResetNotificationSettingsResponse
Resets the *custom notification setting* to IAM Roles Anywhere default setting.
-
#tag_resource(params = {}) ⇒ Struct
Attaches tags to a resource.
-
#untag_resource(params = {}) ⇒ Struct
Removes tags from the resource.
-
#update_crl(params = {}) ⇒ Types::CrlDetailResponse
Updates the certificate revocation list (CRL).
-
#update_profile(params = {}) ⇒ Types::ProfileDetailResponse
Updates a profile, a list of the roles that IAM Roles Anywhere service is trusted to assume.
-
#update_trust_anchor(params = {}) ⇒ Types::TrustAnchorDetailResponse
Updates a trust anchor.
Class Method Summary collapse
- .errors_module ⇒ Object private
Instance Method Summary collapse
- #build_request(operation_name, params = {}) ⇒ Object private
-
#initialize(options) ⇒ Client
constructor
A new instance of Client.
- #waiter_names ⇒ Object deprecated private Deprecated.
Constructor Details
#initialize(options) ⇒ Client
Returns a new instance of Client.
471 472 473 |
# File 'lib/aws-sdk-rolesanywhere/client.rb', line 471 def initialize(*args) super end |
Class Attribute Details
.identifier ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
2245 2246 2247 |
# File 'lib/aws-sdk-rolesanywhere/client.rb', line 2245 def identifier @identifier end |
Class Method Details
.errors_module ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
2248 2249 2250 |
# File 'lib/aws-sdk-rolesanywhere/client.rb', line 2248 def errors_module Errors end |
Instance Method Details
#build_request(operation_name, params = {}) ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
2218 2219 2220 2221 2222 2223 2224 2225 2226 2227 2228 2229 2230 2231 2232 2233 2234 |
# File 'lib/aws-sdk-rolesanywhere/client.rb', line 2218 def build_request(operation_name, params = {}) handlers = @handlers.for(operation_name) tracer = config.telemetry_provider.tracer_provider.tracer( Aws::Telemetry.module_to_tracer_name('Aws::RolesAnywhere') ) context = Seahorse::Client::RequestContext.new( operation_name: operation_name, operation: config.api.operation(operation_name), client: self, params: params, config: config, tracer: tracer ) context[:gem_name] = 'aws-sdk-rolesanywhere' context[:gem_version] = '1.52.0' Seahorse::Client::Request.new(handlers, context) end |
#create_profile(params = {}) ⇒ Types::ProfileDetailResponse
Creates a profile, a list of the roles that Roles Anywhere service is trusted to assume. You use profiles to intersect permissions with IAM managed policies.
Required permissions: ‘rolesanywhere:CreateProfile`.
572 573 574 575 |
# File 'lib/aws-sdk-rolesanywhere/client.rb', line 572 def create_profile(params = {}, = {}) req = build_request(:create_profile, params) req.send_request() end |
#create_trust_anchor(params = {}) ⇒ Types::TrustAnchorDetailResponse
Creates a trust anchor to establish trust between IAM Roles Anywhere and your certificate authority (CA). You can define a trust anchor as a reference to an Private Certificate Authority (Private CA) or by uploading a CA certificate. Your Amazon Web Services workloads can authenticate with the trust anchor using certificates issued by the CA in exchange for temporary Amazon Web Services credentials.
Required permissions: ‘rolesanywhere:CreateTrustAnchor`.
655 656 657 658 |
# File 'lib/aws-sdk-rolesanywhere/client.rb', line 655 def create_trust_anchor(params = {}, = {}) req = build_request(:create_trust_anchor, params) req.send_request() end |
#delete_attribute_mapping(params = {}) ⇒ Types::DeleteAttributeMappingResponse
Delete an entry from the attribute mapping rules enforced by a given profile.
755 756 757 758 |
# File 'lib/aws-sdk-rolesanywhere/client.rb', line 755 def delete_attribute_mapping(params = {}, = {}) req = build_request(:delete_attribute_mapping, params) req.send_request() end |
#delete_crl(params = {}) ⇒ Types::CrlDetailResponse
Deletes a certificate revocation list (CRL).
Required permissions: ‘rolesanywhere:DeleteCrl`.
792 793 794 795 |
# File 'lib/aws-sdk-rolesanywhere/client.rb', line 792 def delete_crl(params = {}, = {}) req = build_request(:delete_crl, params) req.send_request() end |
#delete_profile(params = {}) ⇒ Types::ProfileDetailResponse
Deletes a profile.
Required permissions: ‘rolesanywhere:DeleteProfile`.
840 841 842 843 |
# File 'lib/aws-sdk-rolesanywhere/client.rb', line 840 def delete_profile(params = {}, = {}) req = build_request(:delete_profile, params) req.send_request() end |
#delete_trust_anchor(params = {}) ⇒ Types::TrustAnchorDetailResponse
Deletes a trust anchor.
Required permissions: ‘rolesanywhere:DeleteTrustAnchor`.
884 885 886 887 |
# File 'lib/aws-sdk-rolesanywhere/client.rb', line 884 def delete_trust_anchor(params = {}, = {}) req = build_request(:delete_trust_anchor, params) req.send_request() end |
#disable_crl(params = {}) ⇒ Types::CrlDetailResponse
Disables a certificate revocation list (CRL).
Required permissions: ‘rolesanywhere:DisableCrl`.
921 922 923 924 |
# File 'lib/aws-sdk-rolesanywhere/client.rb', line 921 def disable_crl(params = {}, = {}) req = build_request(:disable_crl, params) req.send_request() end |
#disable_profile(params = {}) ⇒ Types::ProfileDetailResponse
Disables a profile. When disabled, temporary credential requests with this profile fail.
Required permissions: ‘rolesanywhere:DisableProfile`.
970 971 972 973 |
# File 'lib/aws-sdk-rolesanywhere/client.rb', line 970 def disable_profile(params = {}, = {}) req = build_request(:disable_profile, params) req.send_request() end |
#disable_trust_anchor(params = {}) ⇒ Types::TrustAnchorDetailResponse
Disables a trust anchor. When disabled, temporary credential requests specifying this trust anchor are unauthorized.
Required permissions: ‘rolesanywhere:DisableTrustAnchor`.
1015 1016 1017 1018 |
# File 'lib/aws-sdk-rolesanywhere/client.rb', line 1015 def disable_trust_anchor(params = {}, = {}) req = build_request(:disable_trust_anchor, params) req.send_request() end |
#enable_crl(params = {}) ⇒ Types::CrlDetailResponse
Enables a certificate revocation list (CRL). When enabled, certificates stored in the CRL are unauthorized to receive session credentials.
Required permissions: ‘rolesanywhere:EnableCrl`.
1054 1055 1056 1057 |
# File 'lib/aws-sdk-rolesanywhere/client.rb', line 1054 def enable_crl(params = {}, = {}) req = build_request(:enable_crl, params) req.send_request() end |
#enable_profile(params = {}) ⇒ Types::ProfileDetailResponse
Enables temporary credential requests for a profile.
Required permissions: ‘rolesanywhere:EnableProfile`.
1102 1103 1104 1105 |
# File 'lib/aws-sdk-rolesanywhere/client.rb', line 1102 def enable_profile(params = {}, = {}) req = build_request(:enable_profile, params) req.send_request() end |
#enable_trust_anchor(params = {}) ⇒ Types::TrustAnchorDetailResponse
Enables a trust anchor. When enabled, certificates in the trust anchor chain are authorized for trust validation.
Required permissions: ‘rolesanywhere:EnableTrustAnchor`.
1147 1148 1149 1150 |
# File 'lib/aws-sdk-rolesanywhere/client.rb', line 1147 def enable_trust_anchor(params = {}, = {}) req = build_request(:enable_trust_anchor, params) req.send_request() end |
#get_crl(params = {}) ⇒ Types::CrlDetailResponse
Gets a certificate revocation list (CRL).
Required permissions: ‘rolesanywhere:GetCrl`.
1184 1185 1186 1187 |
# File 'lib/aws-sdk-rolesanywhere/client.rb', line 1184 def get_crl(params = {}, = {}) req = build_request(:get_crl, params) req.send_request() end |
#get_profile(params = {}) ⇒ Types::ProfileDetailResponse
Gets a profile.
Required permissions: ‘rolesanywhere:GetProfile`.
1232 1233 1234 1235 |
# File 'lib/aws-sdk-rolesanywhere/client.rb', line 1232 def get_profile(params = {}, = {}) req = build_request(:get_profile, params) req.send_request() end |
#get_subject(params = {}) ⇒ Types::SubjectDetailResponse
Gets a subject, which associates a certificate identity with authentication attempts. The subject stores auditing information such as the status of the last authentication attempt, the certificate data used in the attempt, and the last time the associated identity attempted authentication.
Required permissions: ‘rolesanywhere:GetSubject`.
1284 1285 1286 1287 |
# File 'lib/aws-sdk-rolesanywhere/client.rb', line 1284 def get_subject(params = {}, = {}) req = build_request(:get_subject, params) req.send_request() end |
#get_trust_anchor(params = {}) ⇒ Types::TrustAnchorDetailResponse
Gets a trust anchor.
Required permissions: ‘rolesanywhere:GetTrustAnchor`.
1328 1329 1330 1331 |
# File 'lib/aws-sdk-rolesanywhere/client.rb', line 1328 def get_trust_anchor(params = {}, = {}) req = build_request(:get_trust_anchor, params) req.send_request() end |
#import_crl(params = {}) ⇒ Types::CrlDetailResponse
Imports the certificate revocation list (CRL). A CRL is a list of certificates that have been revoked by the issuing certificate Authority (CA).In order to be properly imported, a CRL must be in PEM format. IAM Roles Anywhere validates against the CRL before issuing credentials.
Required permissions: ‘rolesanywhere:ImportCrl`.
1391 1392 1393 1394 |
# File 'lib/aws-sdk-rolesanywhere/client.rb', line 1391 def import_crl(params = {}, = {}) req = build_request(:import_crl, params) req.send_request() end |
#list_crls(params = {}) ⇒ Types::ListCrlsResponse
Lists all certificate revocation lists (CRL) in the authenticated account and Amazon Web Services Region.
Required permissions: ‘rolesanywhere:ListCrls`.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1440 1441 1442 1443 |
# File 'lib/aws-sdk-rolesanywhere/client.rb', line 1440 def list_crls(params = {}, = {}) req = build_request(:list_crls, params) req.send_request() end |
#list_profiles(params = {}) ⇒ Types::ListProfilesResponse
Lists all profiles in the authenticated account and Amazon Web Services Region.
Required permissions: ‘rolesanywhere:ListProfiles`.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1500 1501 1502 1503 |
# File 'lib/aws-sdk-rolesanywhere/client.rb', line 1500 def list_profiles(params = {}, = {}) req = build_request(:list_profiles, params) req.send_request() end |
#list_subjects(params = {}) ⇒ Types::ListSubjectsResponse
Lists the subjects in the authenticated account and Amazon Web Services Region.
Required permissions: ‘rolesanywhere:ListSubjects`.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1548 1549 1550 1551 |
# File 'lib/aws-sdk-rolesanywhere/client.rb', line 1548 def list_subjects(params = {}, = {}) req = build_request(:list_subjects, params) req.send_request() end |
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceResponse
Lists the tags attached to the resource.
Required permissions: ‘rolesanywhere:ListTagsForResource`.
1580 1581 1582 1583 |
# File 'lib/aws-sdk-rolesanywhere/client.rb', line 1580 def (params = {}, = {}) req = build_request(:list_tags_for_resource, params) req.send_request() end |
#list_trust_anchors(params = {}) ⇒ Types::ListTrustAnchorsResponse
Lists the trust anchors in the authenticated account and Amazon Web Services Region.
Required permissions: ‘rolesanywhere:ListTrustAnchors`.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1636 1637 1638 1639 |
# File 'lib/aws-sdk-rolesanywhere/client.rb', line 1636 def list_trust_anchors(params = {}, = {}) req = build_request(:list_trust_anchors, params) req.send_request() end |
#put_attribute_mapping(params = {}) ⇒ Types::PutAttributeMappingResponse
Put an entry in the attribute mapping rules that will be enforced by a given profile. A mapping specifies a certificate field and one or more specifiers that have contextual meanings.
1742 1743 1744 1745 |
# File 'lib/aws-sdk-rolesanywhere/client.rb', line 1742 def put_attribute_mapping(params = {}, = {}) req = build_request(:put_attribute_mapping, params) req.send_request() end |
#put_notification_settings(params = {}) ⇒ Types::PutNotificationSettingsResponse
Attaches a list of *notification settings* to a trust anchor.
A notification setting includes information such as event name, threshold, status of the notification setting, and the channel to notify.
Required permissions: ‘rolesanywhere:PutNotificationSettings`.
1849 1850 1851 1852 |
# File 'lib/aws-sdk-rolesanywhere/client.rb', line 1849 def put_notification_settings(params = {}, = {}) req = build_request(:put_notification_settings, params) req.send_request() end |
#reset_notification_settings(params = {}) ⇒ Types::ResetNotificationSettingsResponse
Resets the *custom notification setting* to IAM Roles Anywhere default setting.
Required permissions: ‘rolesanywhere:ResetNotificationSettings`.
1951 1952 1953 1954 |
# File 'lib/aws-sdk-rolesanywhere/client.rb', line 1951 def reset_notification_settings(params = {}, = {}) req = build_request(:reset_notification_settings, params) req.send_request() end |
#tag_resource(params = {}) ⇒ Struct
Attaches tags to a resource.
Required permissions: ‘rolesanywhere:TagResource`.
1984 1985 1986 1987 |
# File 'lib/aws-sdk-rolesanywhere/client.rb', line 1984 def tag_resource(params = {}, = {}) req = build_request(:tag_resource, params) req.send_request() end |
#untag_resource(params = {}) ⇒ Struct
Removes tags from the resource.
Required permissions: ‘rolesanywhere:UntagResource`.
2012 2013 2014 2015 |
# File 'lib/aws-sdk-rolesanywhere/client.rb', line 2012 def untag_resource(params = {}, = {}) req = build_request(:untag_resource, params) req.send_request() end |
#update_crl(params = {}) ⇒ Types::CrlDetailResponse
Updates the certificate revocation list (CRL). A CRL is a list of certificates that have been revoked by the issuing certificate authority (CA). IAM Roles Anywhere validates against the CRL before issuing credentials.
Required permissions: ‘rolesanywhere:UpdateCrl`.
2060 2061 2062 2063 |
# File 'lib/aws-sdk-rolesanywhere/client.rb', line 2060 def update_crl(params = {}, = {}) req = build_request(:update_crl, params) req.send_request() end |
#update_profile(params = {}) ⇒ Types::ProfileDetailResponse
Updates a profile, a list of the roles that IAM Roles Anywhere service is trusted to assume. You use profiles to intersect permissions with IAM managed policies.
Required permissions: ‘rolesanywhere:UpdateProfile`.
2145 2146 2147 2148 |
# File 'lib/aws-sdk-rolesanywhere/client.rb', line 2145 def update_profile(params = {}, = {}) req = build_request(:update_profile, params) req.send_request() end |
#update_trust_anchor(params = {}) ⇒ Types::TrustAnchorDetailResponse
Updates a trust anchor. You establish trust between IAM Roles Anywhere and your certificate authority (CA) by configuring a trust anchor. You can define a trust anchor as a reference to an Private Certificate Authority (Private CA) or by uploading a CA certificate. Your Amazon Web Services workloads can authenticate with the trust anchor using certificates issued by the CA in exchange for temporary Amazon Web Services credentials.
Required permissions: ‘rolesanywhere:UpdateTrustAnchor`.
2209 2210 2211 2212 |
# File 'lib/aws-sdk-rolesanywhere/client.rb', line 2209 def update_trust_anchor(params = {}, = {}) req = build_request(:update_trust_anchor, params) req.send_request() end |
#waiter_names ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
2238 2239 2240 |
# File 'lib/aws-sdk-rolesanywhere/client.rb', line 2238 def waiter_names [] end |